==> nimbus-sample-1.1.1.zip: nimbus-sample/beans/ex3/Main.java <==

import java.util.*;

import jp.ossc.nimbus.beans.dataset.*;

/**
 * TvRsNXB
 */
public class Main{
    
    public static final void main(String[] args) throws Exception{
        
        System.out.println("//////// 1\݂̂̃f[^Zbg ///////////");
        // f[^ZbgFdataset1
        // f[^\F1\łQ̃vpeB
        //   vpeB        ^
        //         A        java.lang.String
        //         B        int
        final DataSet dataset1 = new DataSet("dataset1");
        dataset1.setHeaderSchema(
            ":A,java.lang.String" + '\n'
            + ":B,int"
        );
        System.out.println("Ef[^Zbg");
        System.out.println(dataset1);
        
        // 1\\wb_擾
        final Header dataset1_header = dataset1.getHeader();
        System.out.println("Ewb_̃XL[}`");
        System.out.println(dataset1_header.getSchema());
        
        System.out.println("Ef[^̐ݒEyю擾");
        // vpeBAɒlݒ肷
        dataset1_header.setProperty("A", "hoge");
        
        // vpeBAl擾
        System.out.println("A=" + dataset1_header.getStringProperty("A"));
        
        // vpeBBɒlݒ肷
        dataset1_header.setProperty("B", 100);
        
        // vpeBBl擾
        System.out.println("B=" + dataset1_header.getIntProperty("B"));
        
        System.out.println("Esȃf[^̐ݒ");
        // vpeBAɒ`Ă^Ɣ݊Ȍ^̒lݒ肷
        try{
            dataset1_header.setProperty("A", 100);
        }catch(PropertySetException e){
            // O
            System.out.println("^݊łI" + e.getMessage());
        }
        
        // ݂ȂvpeBCɒlݒ肷
        try{
            dataset1_header.setProperty("C", 100);
        }catch(PropertySetException e){
            // O
            System.out.println("݂ȂvpeBłI" + e.getMessage());
        }
        
        
        
        System.out.println();
        System.out.println("//////// 2\݂̂̃f[^Zbg ///////////");
        // f[^ZbgFdataset2
        // f[^\F2\łQ̃vpeB
        //   vpeB        ^
        //         A        java.lang.String
        //         B        int
        final DataSet dataset2 = new DataSet("dataset2");
        dataset2.setRecordListSchema(
            ":A,java.lang.String" + '\n'
            + ":B,int"
        );
        System.out.println("Ef[^Zbg");
        System.out.println(dataset2);
        
        // 2\\郌R[hXg擾
        final RecordList dataset2_recordList = dataset2.getRecordList();
        System.out.println("ER[hXg̃XL[}`");
        System.out.println(dataset2_recordList.getSchema());
        
        // R[h𐶐
        System.out.println("ER[h1̐");
        final Record dataset2_recordList_record1
             = dataset2_recordList.createRecord();
        System.out.println("ER[h1̃XL[}`");
        System.out.println(dataset2_recordList_record1.getSchema());
        System.out.println("Ef[^̐ݒEyю擾");
        // vpeBAɒlݒ肷
        dataset2_recordList_record1.setProperty("A", "hoge");
        // vpeBAl擾
        System.out.println("A=" + dataset2_recordList_record1.getStringProperty("A"));
        // vpeBBɒlݒ肷
        dataset2_recordList_record1.setProperty("B", 100);
        // vpeBBl擾
        System.out.println("B=" + dataset2_recordList_record1.getIntProperty("B"));
        // R[hXgɃR[hǉ
        dataset2_recordList.addRecord(dataset2_recordList_record1);
        
        System.out.println("ER[h2̐");
        final Record dataset2_recordList_record2
             = dataset2_recordList.createRecord();
        System.out.println("ER[h2̃XL[}`");
        System.out.println(dataset2_recordList_record2.getSchema());
        System.out.println("Ef[^̐ݒEyю擾");
        // vpeBAɒlݒ肷
        dataset2_recordList_record2.setProperty("A", "fuga");
        // vpeBAl擾
        System.out.println("A=" + dataset2_recordList_record2.getStringProperty("A"));
        // vpeBBɒlݒ肷
        dataset2_recordList_record2.setProperty("B", 200);
        // vpeBBl擾
        System.out.println("B=" + dataset2_recordList_record2.getIntProperty("B"));
        // R[hXgɃR[hǉ
        dataset2_recordList.addRecord(dataset2_recordList_record2);
        
        System.out.println("ER[hXg̃R[h̎擾");
        System.out.println("R[h=" + dataset2_recordList.size());
        Iterator records = dataset2_recordList.iterator();
        while(records.hasNext()){
            final Record record = (Record)records.next();
            final Iterator entries = record.entrySet().iterator();
            while(entries.hasNext()){
                final Map.Entry entry = (Map.Entry)entries.next();
                System.out.print(entry.getKey() + "=" + entry.getValue());
                if(entries.hasNext()){
                    System.out.print(", ");
                }
            }
            System.out.println();
        }
        
        
        
        System.out.println();
        System.out.println("//////// 1\2\𕹂f[^Zbg ///////////");
        // f[^ZbgFdataset3
        // f[^\F1\łQ̃vpeB
        //   vpeB      ^          ͕ϊ o͕ϊ  
        //         A      java.lang.String    g     pfBO   null
        //         B      int               l   J}ҏW   1000ȏ
        //             2\łR̃vpeB
        //   vpeB      ^          ͕ϊ o͕ϊ  
        //         A      java.lang.String
        //         B      int
        //         C      java.util.Date   yyMMddDate
        final DataSet dataset3 = new DataSet("dataset3");
        dataset3.setSchema(
            //wb_̃XL[}
            ":A,java.lang.String,\"jp.ossc.nimbus.util.converter.PaddingStringConverter{2,,3}\",\"jp.ossc.nimbus.util.converter.PaddingStringConverter{1,10,2}\",@value@!=null" + '\n'
            + ":B,int,\"jp.ossc.nimbus.util.converter.DecimalFormatConverter{2,#}\",\"jp.ossc.nimbus.util.converter.DecimalFormatConverter{1,###\\,###\\,###}\",@value@>=1000",
            //R[hXg̃XL[}
            ":A,java.lang.String" + '\n'
            + ":B,int" + '\n'
            + ":C,java.util.Date,\"jp.ossc.nimbus.util.converter.DateFormatConverter{2,yyMMdd}\""
        );
        System.out.println("Ef[^Zbg");
        System.out.println(dataset3);
        
        // 1\\wb_擾
        final Header dataset3_header = dataset3.getHeader();
        System.out.println("Ewb_̃XL[}`");
        System.out.println(dataset3_header.getSchema());
        
        System.out.println("Ef[^̐ݒEyю擾");
        
        // vpeBAɃp[Xlݒ肷
        dataset3_header.setParseProperty("A", "   hoge   ");
        
        // vpeBAl擾
        System.out.println("A=\"" + dataset3_header.getStringProperty("A") + '"');
        
        // vpeBAtH[}bgl擾
        System.out.println("A(tH[}bgς)=\"" + dataset3_header.getFormatProperty("A") + '"');
        
        // vpeBBɃp[Xlݒ肷
        dataset3_header.setParseProperty("B", "10200");
        
        // vpeBBl擾
        System.out.println("B=" + dataset3_header.getIntProperty("B"));
        
        // vpeBBtH[}bgl擾
        System.out.println("B(tH[}bgς)=" + dataset3_header.getFormatProperty("B"));
        
        System.out.println("Esȃf[^̐ݒ");
        // vpeBAnull̒lݒ肷
        try{
            dataset3_header.setProperty("A", null);
        }catch(PropertySetException e){
            // O
            System.out.println("lnullłI" + e.getMessage());
        }
        
        // vpeBB1000ȉ̒lݒ肷
        try{
            dataset3_header.setProperty("B", 100);
        }catch(PropertySetException e){
            // O
            System.out.println("l1000菬łI" + e.getMessage());
        }
        
        // 2\\郌R[hXg擾
        final RecordList dataset3_recordList = dataset3.getRecordList();
        System.out.println("ER[hXg̃XL[}`");
        System.out.println(dataset3_recordList.getSchema());
        
        // R[h𐶐
        System.out.println("ER[h1̐");
        final Record dataset3_recordList_record1
             = dataset3_recordList.createRecord();
        // vpeBAɒlݒ肷
        dataset3_recordList_record1.setProperty("A", "hoge");
        // vpeBBɒlݒ肷
        dataset3_recordList_record1.setProperty("B", 100);
        // vpeBCɒlݒ肷
        dataset3_recordList_record1.setParseProperty("C", "071109");
        // R[hXgɃR[hǉ
        dataset3_recordList.addRecord(dataset3_recordList_record1);
        System.out.println("R[h1 : " + dataset3_recordList_record1);
        
        System.out.println("ER[h2̐");
        final Record dataset3_recordList_record2
             = dataset3_recordList.createRecord();
        // vpeBAɒlݒ肷
        dataset3_recordList_record2.setProperty("A", "fuga");
        // vpeBBɒlݒ肷
        dataset3_recordList_record2.setProperty("B", 200);
        // vpeBCɒlݒ肷
        dataset3_recordList_record2.setParseProperty("C", "071110");
        // R[hXgɃR[hǉ
        dataset3_recordList.addRecord(dataset3_recordList_record2);
        System.out.println("R[hQ : " + dataset3_recordList_record2);
        
        System.out.println("ER[hXg̃R[h̎擾");
        System.out.println("R[h=" + dataset3_recordList.size());
        records = dataset3_recordList.iterator();
        while(records.hasNext()){
            final Record record = (Record)records.next();
            final Iterator entries = record.entrySet().iterator();
            while(entries.hasNext()){
                final Map.Entry entry = (Map.Entry)entries.next();
                System.out.print(entry.getKey() + "=" + entry.getValue());
                if(entries.hasNext()){
                    System.out.print(", ");
                }
            }
            System.out.println();
        }
    }
}

==> nimbus-sample-1.1.9.zip: nimbus-sample/beans/ex3/Main.java <==

import java.util.*;

import jp.ossc.nimbus.beans.dataset.*;

/**
 * TvRsNXB
 */
public class Main{
    
    public static final void main(String[] args) throws Exception{
        
        System.out.println("//////// 1\݂̂̃f[^Zbg ///////////");
        // f[^ZbgFdataset1
        // f[^\F1\łQ̃vpeB
        //   vpeB        ^
        //         A        java.lang.String
        //         B        int
        final DataSet dataset1 = new DataSet("dataset1");
        dataset1.setHeaderSchema(
            ":A,java.lang.String" + '\n'
            + ":B,int"
        );
        System.out.println("Ef[^Zbg");
        System.out.println(dataset1);
        
        // 1\\wb_擾
        final Header dataset1_header = dataset1.getHeader();
        System.out.println("Ewb_̃XL[}`");
        System.out.println(dataset1_header.getSchema());
        
        System.out.println("Ef[^̐ݒEyю擾");
        // vpeBAɒlݒ肷
        dataset1_header.setProperty("A", "hoge");
        
        // vpeBAl擾
        System.out.println("A=" + dataset1_header.getStringProperty("A"));
        
        // vpeBBɒlݒ肷
        dataset1_header.setProperty("B", 100);
        
        // vpeBBl擾
        System.out.println("B=" + dataset1_header.getIntProperty("B"));
        
        System.out.println("Esȃf[^̐ݒ");
        // vpeBAɒ`Ă^Ɣ݊Ȍ^̒lݒ肷
        try{
            dataset1_header.setProperty("A", 100);
        }catch(PropertySetException e){
            // O
            System.out.println("^݊łI" + e.getMessage());
        }
        
        // ݂ȂvpeBCɒlݒ肷
        try{
            dataset1_header.setProperty("C", 100);
        }catch(PropertySetException e){
            // O
            System.out.println("݂ȂvpeBłI" + e.getMessage());
        }
        
        
        
        System.out.println();
        System.out.println("//////// 2\݂̂̃f[^Zbg ///////////");
        // f[^ZbgFdataset2
        // f[^\F2\łQ̃vpeB
        //   vpeB        ^
        //         A        java.lang.String
        //         B        int
        final DataSet dataset2 = new DataSet("dataset2");
        dataset2.setRecordListSchema(
            ":A,java.lang.String" + '\n'
            + ":B,int"
        );
        System.out.println("Ef[^Zbg");
        System.out.println(dataset2);
        
        // 2\\郌R[hXg擾
        final RecordList dataset2_recordList = dataset2.getRecordList();
        System.out.println("ER[hXg̃XL[}`");
        System.out.println(dataset2_recordList.getSchema());
        
        // R[h𐶐
        System.out.println("ER[h1̐");
        final Record dataset2_recordList_record1
             = dataset2_recordList.createRecord();
        System.out.println("ER[h1̃XL[}`");
        System.out.println(dataset2_recordList_record1.getSchema());
        System.out.println("Ef[^̐ݒEyю擾");
        // vpeBAɒlݒ肷
        dataset2_recordList_record1.setProperty("A", "hoge");
        // vpeBAl擾
        System.out.println("A=" + dataset2_recordList_record1.getStringProperty("A"));
        // vpeBBɒlݒ肷
        dataset2_recordList_record1.setProperty("B", 100);
        // vpeBBl擾
        System.out.println("B=" + dataset2_recordList_record1.getIntProperty("B"));
        // R[hXgɃR[hǉ
        dataset2_recordList.addRecord(dataset2_recordList_record1);
        
        System.out.println("ER[h2̐");
        final Record dataset2_recordList_record2
             = dataset2_recordList.createRecord();
        System.out.println("ER[h2̃XL[}`");
        System.out.println(dataset2_recordList_record2.getSchema());
        System.out.println("Ef[^̐ݒEyю擾");
        // vpeBAɒlݒ肷
        dataset2_recordList_record2.setProperty("A", "fuga");
        // vpeBAl擾
        System.out.println("A=" + dataset2_recordList_record2.getStringProperty("A"));
        // vpeBBɒlݒ肷
        dataset2_recordList_record2.setProperty("B", 200);
        // vpeBBl擾
        System.out.println("B=" + dataset2_recordList_record2.getIntProperty("B"));
        // R[hXgɃR[hǉ
        dataset2_recordList.addRecord(dataset2_recordList_record2);
        
        System.out.println("ER[hXg̃R[h̎擾");
        System.out.println("R[h=" + dataset2_recordList.size());
        Iterator records = dataset2_recordList.iterator();
        while(records.hasNext()){
            final Record record = (Record)records.next();
            final Iterator entries = record.entrySet().iterator();
            while(entries.hasNext()){
                final Map.Entry entry = (Map.Entry)entries.next();
                System.out.print(entry.getKey() + "=" + entry.getValue());
                if(entries.hasNext()){
                    System.out.print(", ");
                }
            }
            System.out.println();
        }
        
        
        
        System.out.println();
        System.out.println("//////// 1\2\𕹂f[^Zbg ///////////");
        // f[^ZbgFdataset3
        // f[^\F1\łQ̃vpeB
        //   vpeB      ^          ͕ϊ o͕ϊ  
        //         A      java.lang.String    g     pfBO   null
        //         B      int               l   J}ҏW   1000ȏ
        //             2\łR̃vpeB
        //   vpeB      ^          ͕ϊ o͕ϊ  
        //         A      java.lang.String
        //         B      int
        //         C      java.util.Date   yyMMddDate
        final DataSet dataset3 = new DataSet("dataset3");
        dataset3.setSchema(
            //wb_̃XL[}
            ":A,java.lang.String,\"jp.ossc.nimbus.util.converter.PaddingStringConverter{2,,3}\",\"jp.ossc.nimbus.util.converter.PaddingStringConverter{1,10,2}\",@value@!=null" + '\n'
            + ":B,long,\"jp.ossc.nimbus.util.converter.DecimalFormatConverter{2,#}\",\"jp.ossc.nimbus.util.converter.DecimalFormatConverter{1,###\\,###\\,###}\",@value@>=1000",
            //R[hXg̃XL[}
            ":A,java.lang.String" + '\n'
            + ":B,int" + '\n'
            + ":C,java.util.Date,\"jp.ossc.nimbus.util.converter.DateFormatConverter{2,yyMMdd}\""
        );
        System.out.println("Ef[^Zbg");
        System.out.println(dataset3);
        
        // 1\\wb_擾
        final Header dataset3_header = dataset3.getHeader();
        System.out.println("Ewb_̃XL[}`");
        System.out.println(dataset3_header.getSchema());
        
        System.out.println("Ef[^̐ݒEyю擾");
        
        // vpeBAɃp[Xlݒ肷
        dataset3_header.setParseProperty("A", "   hoge   ");
        
        // vpeBAl擾
        System.out.println("A=\"" + dataset3_header.getStringProperty("A") + '"');
        
        // vpeBAtH[}bgl擾
        System.out.println("A(tH[}bgς)=\"" + dataset3_header.getFormatProperty("A") + '"');
        
        // vpeBBɃp[Xlݒ肷
        dataset3_header.setParseProperty("B", "10200");
        
        // vpeBBl擾
        System.out.println("B=" + dataset3_header.getIntProperty("B"));
        
        // vpeBBtH[}bgl擾
        System.out.println("B(tH[}bgς)=" + dataset3_header.getFormatProperty("B"));
        
        System.out.println("Esȃf[^̐ݒ");
        // vpeBAnull̒lݒ肷
        try{
            dataset3_header.setProperty("A", null);
        }catch(PropertySetException e){
            // O
            System.out.println("lnullłI" + e.getMessage());
        }
        
        // vpeBB1000ȉ̒lݒ肷
        try{
            dataset3_header.setProperty("B", 100);
        }catch(PropertySetException e){
            // O
            System.out.println("l1000菬łI" + e.getMessage());
        }
        
        // 2\\郌R[hXg擾
        final RecordList dataset3_recordList = dataset3.getRecordList();
        System.out.println("ER[hXg̃XL[}`");
        System.out.println(dataset3_recordList.getSchema());
        
        // R[h𐶐
        System.out.println("ER[h1̐");
        final Record dataset3_recordList_record1
             = dataset3_recordList.createRecord();
        // vpeBAɒlݒ肷
        dataset3_recordList_record1.setProperty("A", "hoge");
        // vpeBBɒlݒ肷
        dataset3_recordList_record1.setProperty("B", 100);
        // vpeBCɒlݒ肷
        dataset3_recordList_record1.setParseProperty("C", "071109");
        // R[hXgɃR[hǉ
        dataset3_recordList.addRecord(dataset3_recordList_record1);
        System.out.println("R[h1 : " + dataset3_recordList_record1);
        
        System.out.println("ER[h2̐");
        final Record dataset3_recordList_record2
             = dataset3_recordList.createRecord();
        // vpeBAɒlݒ肷
        dataset3_recordList_record2.setProperty("A", "fuga");
        // vpeBBɒlݒ肷
        dataset3_recordList_record2.setProperty("B", 200);
        // vpeBCɒlݒ肷
        dataset3_recordList_record2.setParseProperty("C", "071110");
        // R[hXgɃR[hǉ
        dataset3_recordList.addRecord(dataset3_recordList_record2);
        System.out.println("R[hQ : " + dataset3_recordList_record2);
        
        System.out.println("ER[hXg̃R[h̎擾");
        System.out.println("R[h=" + dataset3_recordList.size());
        records = dataset3_recordList.iterator();
        while(records.hasNext()){
            final Record record = (Record)records.next();
            final Iterator entries = record.entrySet().iterator();
            while(entries.hasNext()){
                final Map.Entry entry = (Map.Entry)entries.next();
                System.out.print(entry.getKey() + "=" + entry.getValue());
                if(entries.hasNext()){
                    System.out.print(", ");
                }
            }
            System.out.println();
        }
        
        
        
        System.out.println();
        System.out.println("//////// 1\2\Ԃ炳f[^Zbg ///////////");
        // f[^ZbgFdataset1
        // f[^\F1\łQ̃vpeBÂ̂P2\
        //   vpeB        ^
        //         A        java.lang.String
        //         B        jp.ossc.nimbus.beans.dataset.RecordList
        //                  vpeB        ^
        //                        C         java.lang.String
        //                        D         int
        final DataSet dataset4 = new DataSet("dataset4");
        dataset4.setHeaderSchema(
            ":A,java.lang.String" + '\n'
            + "LIST:B,BList"
        );
        dataset4.setNestedRecordListSchema(
            "BList",
            ":C,java.lang.String" + '\n'
            + ":D,int"
        );
        System.out.println("Ef[^Zbg");
        System.out.println(dataset4);
        
        // 1\\wb_擾
        final Header dataset4_header = dataset4.getHeader();
        System.out.println("Ewb_̃XL[}`");
        System.out.println(dataset4_header.getSchema());
        
        System.out.println("Ef[^̐ݒ");
        // vpeBAɒlݒ肷
        dataset4_header.setProperty("A", "hoge");
        
        // vpeBAl擾
        System.out.println("A=" + dataset4_header.getStringProperty("A"));
        
        // vpeBB̃R[hXg𐶐
        RecordList dataset4_header_bList = dataset4.createNestedRecordList("BList");
        System.out.println("ER[hXg̃XL[}`");
        System.out.println(dataset4_header_bList.getSchema());
        
        // R[h𐶐
        System.out.println("ER[h1̐");
        final Record dataset4_header_bList_record1
             = dataset4_header_bList.createRecord();
        // vpeBCɒlݒ肷
        dataset4_header_bList_record1.setProperty("C", "hoge");
        // vpeBDɒlݒ肷
        dataset4_header_bList_record1.setProperty("D", 100);
        // R[hXgɃR[hǉ
        dataset4_header_bList.addRecord(dataset4_header_bList_record1);
        System.out.println("R[h1 : " + dataset4_header_bList_record1);
        
        System.out.println("ER[h2̐");
        final Record dataset4_header_bList_record2
             = dataset4_header_bList.createRecord();
        // vpeBCɒlݒ肷
        dataset4_header_bList_record2.setProperty("C", "hoge");
        // vpeBDɒlݒ肷
        dataset4_header_bList_record2.setProperty("D", 200);
        // R[hXgɃR[hǉ
        dataset4_header_bList.addRecord(dataset4_header_bList_record2);
        System.out.println("R[h2 : " + dataset4_header_bList_record2);
        
        // vpeBBɃR[hXgݒ肷
        dataset4_header.setProperty("B", dataset4_header_bList);
        
        
        // vpeBAl擾
        System.out.println("A=\"" + dataset4_header.getStringProperty("A") + '"');
        System.out.println("B=");
        System.out.println("R[h=" + dataset4_header_bList.size());
        records = dataset4_header_bList.iterator();
        while(records.hasNext()){
            final Record record = (Record)records.next();
            final Iterator entries = record.entrySet().iterator();
            while(entries.hasNext()){
                final Map.Entry entry = (Map.Entry)entries.next();
                System.out.print(entry.getKey() + "=" + entry.getValue());
                if(entries.hasNext()){
                    System.out.print(", ");
                }
            }
            System.out.println();
        }
    }
}
